COUNTDOWN TO 666 - TvFoutreach
Description: How to count the # of the Beast

###

CountDown to 666...CountDown to 666...

#
WELCOME TO:
•
TvF OUTREACH•

(Public Ministering since 1993)

###

"JESUS CHRIST or the ANTICHRIST... WHOSE SIDE ARE YOU ON"?

###
WE ARE NEARING THE MIDNIGHT HOUR...We don't know the DAY or the HOUR, but it is clearly IMMINENT!

"Choose you this day whom ye shall serve..." Joshua 24:15

#
It's later than you think...The following information should amaze you!

#
WE WELCOME YOUR EMAILS!

# TvFoutreach@webtv.net

##
Disclaimerl All information on this website is: •True •Documented •Not subject to Libel •Protected by the U.S. First Amendment and International Laws l Copyright © 1993 - 2013

###

#
You will find a "LINKED-LIST" of all the Articles on this Website, directly after this next Amazing Article!

### THE HEBREW ALPHABET NUMBERING CHART [How to count the # of the Beast]

### Hebrew name - English = - # Value
1. ALEPH= ' (not the vowel 'a')---------1
2. BEYTH= B---------------------------------2
3. GIYMEL= G-------------------------------3
4. DALETH= D-------------------------------4
5. HE= H---------------------------------------5
6. VAV= W or V------------------------------6
7. ZAYIN= Z-----------------------------------7
8. CHEYTH= CH-----------------------------8
9. TEYTH= T (used after vowels)--------9
10. YOWD= Y or J--------------------------10
11. KAPH= K or C (K sound)-------------20
12. LAMED= L-------------------------------30
13. MEM= M----------------------------------40
14. NUWN= N--------------------------------50
15. CAMEK= S or C (S sound)-----------60
16. 'AYIN= (gutteral sound)---------------70
17. PHE= PH = F-----------------------------80
18. TSADEY=TS-----------------------------90
19. QOWPH= Q-----------------------------100
20. REYSH= R-------------------------------200
21. SIYN= S-----------------------------------300
" " SHIYN= SH-------------------------------300
22. THAV= TH--------------------------------400
" " TAV= *T (used after consonants)---400

### HEBREW DOES NOT HAVE "VOWELS", so, to add up English names in the Hebrew alphabet, "OMIT ALL VOWELS", EXCEPT where the letter "i" has the "ya" sound as in "William". In this case, IN HEBREW, the "i" is actually the CONSONANT "y" (yowd)! So "William" would be spelled "Wllym" (not Wllm), #=116. (When you take the vowels out, you should still be able to sound out the name, even with just the consonants.) Some "long vowels" can be a Hebrew consonant. Otherwise, just match the English consonant with the Hebrew consonant equivalent. Then add up the *Number Value! Note the 2 "T's"! The "Tav" is used in "Clinton"!
•VERY INTERESTINGLY•
"WILLIAM CLINTON" = WLLYM KLNTN ... WLLYM = 116, KLNTN = 550 ... 116 + 550 = 666
You will find the entire HEBREW ALPHABET listed letter by letter in the Bible, in PSALMS 119 (paragraph headings)!
TvF Outreach P.O. Box 42002 Las Vegas, NV 89116 (702) 453-3348 TvFoutreach@webtv.net

###

###
*NOTE: The picture above, is from a CNN news broadcast. There are many false '666 scenarios' floating on the Web. TvF Outreach is simply to report whose name DOES ACCURATELY equal 666 in the Bible's Hebrew (and Greek) alphabets, as William Clinton DOES. Daniel 8:5-25 shows that the Antichrist will rise from the WEST. Think about it; God's prophecies have NEVER FAILED. Obama doesn't = 666, but He and this Economic Crisis does line up with Rev.6:5-6 about the "Black Horse/horseman" and the food/economic crisis it mentions. Click our 'Elections' article below.

###

### After clicking an article from the LIST BELOW... you will need to press "BACK" to return to the LIST for your next selection... to avoid doing a lot of scrolling! Very Important Articles •Click Links Below

###

### LIST OF ARTICLES ON THIS WEBSITE
THE HEBREW ALPHABET NUMBERING CHART
THE RAPTURE
THERE ARE 2 BEASTS
***ELECTIONS 2004-2012***
LIBERTY LOST
THE GREAT TRIBULATION
PLEASE REALIZE--Christians are Peaceful
NATO: THE SLEEPING GIANT
Origin of: THE ROMAN CATHOLIC CHURCH
HUMAN CLONING ALERT
TITUS--OF 70AD REBORN

#
*If you did not click an article from the LIST, just scroll 'up and down' for these same articles!
(Clicking the links is better.)

##
Dell Coupon Code

### THE RAPTURE "For the Lord himself shall descend from heaven with a shout, with the voice of the archangel, and with the trump of God: and the dead in Christ shall rise first: Then we which are ALIVE AND REMAIN shall be CAUGHT UP together with them IN THE CLOUDS, to meet the Lord in the AIR: and so shall we ever be with the Lord. Wherefore comfort one another with these words." (1 Thess. 4:16-18) The Latin word RAPTURE is the commonly used word referring to the biblical Greek word "ARPAGESOMETHA" meaning "we shall be snatched or caught up suddenly"! With the many Bible references to the RAPTURE, one of the most OVERLOOKED, yet commonly read verses, is where Jesus said that his coming would be just "AS IT WAS IN THE DAYS OF NOAH AND LOT"! So let's take a look at these verses! Luke 17: 26-29 says; "And as it was in the days of Noah, so shall it be also in the days of the Son of man. They did eat, they drank, they married wives, they were given in marriage; UNTIL THE DAY THAT NOAH ENTERED INTO THE ARK and the flood came, and destroyed them all. LIKEWISE also as it was in the days of Lot; they did eat, they drank, they bought, they sold, they planted, they builded; But the SAME DAY THAT LOT WENT OUT OF SODOM it rained fire and brimstone from heaven, and destroyed them all." • NOTICE THAT THE DESTRUCTION DID NOT HAPPEN "UNTIL GOD TOOK HIS PEOPLE OUT"! Furthermore, when the ANGEL told LOT that he was going to destroy the city of Sodom, the ANGEL said; "Haste thee, escape thither; for I CANNOT DO ANYTHING till thou be come thither..." (Genesis 19: 22-24). So LIKEWISE...at the "GREAT TRIBULATION"... God will "take out" all of HIS PEOPLE who have accepted the salvation offered "freely" through the atoning blood of Jesus Christ! 1 Corinthians 15: 51-53 shows the IMMORTAL CHANGE that will happen INSTANTLY to God's people at the RAPTURE! Romans 11:25 says that "blindness in part is happened to Israel, until the fullness of the Gentiles be come in." (This is because the Jews, for the most part, rejected Jesus at His 1st coming, and crucified Him.) One of the MAIN reasons that some people are CONFUSED about the RAPTURE is because the book of Revelation says that "saints will be martyred in the Tribulation"! The saints that will be martyred in the Tribulation are Jews, whose eyes were spiritually blinded until the "FULLNESS OF THE GENTILES WOULD COME IN, AND BE TAKEN OUT"! The Bible says that "the first would be last, and the last would be first"! Jesus was meaning that the Jews, who were called first, would come in last, and the Gentiles, who were called last, would come in first! The TRIBULATION is called "the time of JACOB'S (Israel's) TROUBLE"! "Alas! for that day is great, so that none is like it: it is even the time of JACOB'S TROUBLE; but he shall be saved out of it."! (Jer. 30:7) God will open the eyes of the Jews when He sends His 2 Jewish witnesses to preach to them in the Tribulation! (Rev. 11: 3-11) And all Jews who believe will be saved, even if they have to die for their faith in Jesus! But this is the MAIN area of confusion to some people concerning the RAPTURE! It is not that most don't see the clear teachings of the RAPTURE, but some have gotten confused seeing that "saints will be martyred in the Tribulation", and they have not properly understood the clear PROPHECIES ABOUT ISRAEL! So be assured! Jesus WILL snatch up "His Bride" BEFORE the Great Tribulation, which shall come upon all the world---just as God took out Noah and Lot from the "destruction"! IT'S A PROMISE! Revelation 3:10 says; "Because thou hast kept the word of my patience, I also will KEEP THEE FROM the hour of temptation, which shall come upon all the world, to try them that dwell upon the earth." (The word "hour" is mentioned in the book of Revelation as meaning the "Tribulation"! See Rev. 3:10, 14:7, 17:12) So, "Lift up your heads, for your redemption draws nigh"! TvF Outreach P.O. Box 42002 Las Vegas, NV 89116 TvFoutreach@webtv.net

### THERE ARE 2 BEASTS The Bible gives us even more details concerning the "RISE OF THE BEAST", whose number is "666"! "ANOTHER (lesser) BEAST with 2 HORNS" will rise just AFTER the 1ST BEAST has made his big, "1st stage" rise! REVELATION 13:11-15 says, "And I beheld "ANOTHER BEAST" coming up out of the earth; and he had 2 HORNS like a lamb, and he spoke as a dragon... And he EXERCISED ALL THE POWER (jurisdiction, authority {president}) of the FIRST BEAST before him, and caused the earth and them which dwell therein to WORSHIP THE FIRST BEAST...and cause that as many as would not worship the image of the BEAST should be killed." In other words, the "OTHER BEAST with 2 HORNS" holds the SAME JOB the 1ST BEAST (Antichrist) before them held! Then, the '2nd Horn' of the "OTHER BEAST" turns around and forces the entire world to worship the 1ST BEAST! Although the 1st Beast had previously reigned in part--he does not attain "full global power" until sometime after 'BOTH HORNS of the OTHER BEAST' have (one at a time) risen! (ie-- 2 presidents would rise just after the 1st {666} Beast.) Then, after the 2nd horn of the 'other beast' rises, he would command the world to worship the 1st (666) Beast. It looks like the 2nd Horn has risen! TvF OUTREACH P.O. BOX 42002 LAS VEGAS, NV 89116 (702) 453-3348 TvFoutreach@webtv.net

### ***ELECTIONS 2004-2012*** [Obama's Inauguration 1-20-09] [Breaking News on Nov. 6, 2012: Obama wins 2nd term as U.S. President] If George Bush is the '1st horn' of the "OTHER BEAST" mentioned in Revelation 13:11-14, (who looks like a lamb {Christian})... And if Barack Obama is the "2nd horn" of this "SAME Other Beast" (who causes the world to worship the "666 Beast" of Rev. 13:18) ......and if William Clinton is the "1ST BEAST" of Revelation 13 (whose name adds up to "666" in the "Hebrew alphabet").....the following scenario is something to read carefully! Revelation 13:11 says; "And I beheld another beast coming up out of the earth; and he had "2 HORNS" (horns=rulers, ie-- 2 presidents) and he {both horns} exercises ALL THE AUTHORITY of the 1st {666} Beast before him, and causes the earth and them which dwell therein to worship the 1st beast..." Since William Clinton = 666, and is called the "1st Beast" (not horn)... what authority did he have? He was president of the U.S.! Therefore, the "2 horns" in Rev. 13:11 are said to have the SAME AUTHORITY the 666 Beast held (ie--presidents), and that the "2nd horn" of the "Other Beast" would cause the world to worship the 1st beast whose name = 666. The 666 Beast was at first, only president of the U.S., and he cannot become the WORLD RULER, until the "2nd Horn" of the "Other Beast" rises! If Obama is that "2nd Horn", then he would be the one with the authority to command the world to worship the 666 Beast (of which William Clinton equals). We all know the "UNUSUAL" circumstances of Bush's election to President! And we all know the "PROFOUND" events that QUICKLY BEGAN TO HAPPEN!!! Not the least of which was the "HORROR OF 911"!!! Then, soon followed the "WAR IN AFGHANISTAN"...followed quickly by the "GLOBAL TERROR WAR"!!! Then--(one of the main agendas)--"THE WAR ON IRAQ"!!! (Which is all Biblical! See Rev. 17 & 18.) So we see that since the election of Bush--the ENTIRE WORLD has been thrown into a deceptive "GLOBAL TERROR WAR"! But, in this scenario, Bush would only be the "1st horn" of the "2 horns". The President after Bush would be the "2nd horn", to usher in the '666 Antichrist'. NOTE: Barack Obama (1st Black pres.) and this developing "Economic Crisis" bears a NOTABLE resemblance to the "3RD HORSEMAN" of Revelation 6 (which also depicts a food/economic crisis and a black horse). Rev. 6:5,6 says; "...I heard the 3rd beast say, Come and see. And I beheld and lo a BLACK horse; and...a pair of balances in his hand... A measure of wheat for a penny, and three measures of barley for a penny;..." (This will lead to the 'mark of the beast in order to buy and sell'.) The 4th Horseman depicts the '1st (666) Beast' taking full control (accompanied by the False Prophet). TvF OUTREACH P.O. BOX 42002 LAS VEGAS, NV 89116 TvFoutreach@webtv.net

### LIBERTY LOST (A summary compiled by F. Gregory Anderson) There are powerful men seeking to destroy the basic foundations of our liberty. They have been quite successful in their plans so far. They are disrupting the family, corrupting our governments destroying morality, and attacking religious faith and religious freedom. Their objective is to "...eliminate liberty--economic, political, and religious--and establish in its place the most widespread and complete totalitarian system ever to oppress mankind. These men have been working under such perfect disguise that many Americans have not been able to recognize them or their methods." ["Freeman Digest" May, 1978 p.53.] They scheme and plan, manipulate and destroy. They use crime and murder, lies and fear. They are not bound by law, for they control most of the judgment seats. With enough study, it is possible to learn the goals of these power brokers from their own documents. Their goal is worldwide control with themselves in charge. They fully intend to control all governments, control the money, control the military, control the courts, destroy all religions except those that actually teach evil rather than good, and control access to food and medicine. They have a large measure of control over many of these things now. If they gain full control, we will have little recourse except to do what they say, unless we have prepared well in advance. How can a group of individuals so dictate the events of the world? Many times a government creates a crisis, then offers the "solution"--a solution that exchanges one more of our freedoms for some version of government-enforced safety and security. Our response to these crises has become conditioned. We turn to government to take care of us, and they do--at the price of our liberty. When the crisis appears to be worldwide, we turn to a worldwide government, thus playing right into their hands. The Prophet Hosea declared "my people are destroyed for lack of knowledge." [Hosea 4:6.] This summary has been prepared to offer a basic knowledge of the methods being used to obtain control of people and nations. It is hoped that this knowledge will assist us to better uphold correct principles that support the inalienable rights given to all people by God, and oppose programs and proposals that violate these principles. It is recognized that the U.S. Constitution was divinely inspired by God for the very purpose of protecting these inalienable rights. There are several areas that these powerful men seek to control. They are listed and a brief explanation is given of each: • GOVERNMENT: The objective is to create a single government with power to rule the people of the world, sometimes referred to as a new world order. All People will be ruled by the same laws, judicial system, monetary system, religious worship, and armed forces. Every President and Secretary of State since Woodrow Wilson has been a member of a group which is actively pursuing the goal of obliterating national boundaries and establishing a single world government. Known as the Council on Foreign Relations, this group is the American branch of a society which originated in England. David Rockefeller serves as it's Chairman, George Bush is a past Chairman, and Bill Clinton was also a member. [The Shadows of Power, James Perloff, 1988] The effort to achieve this goal is aided by the media, since every major media {newspaper, radio, television, and communications network} is owned by a member or associate. ["FREE" 'The CFR/Trilateral Connection' 1991] At a cost of $10 million to the U.S. taxpayers, the Rockefeller Foundation has developed a "New States Constitution" that is intended to replace the constitution that we now have. This document does not have a Bill of Rights, does not include the right to own firearms, and does not protect freedom of religion. It uses the term "national emergency" 134 times. [A Review & Commentary on Rexford E. Tugwells' book "The Emerging Constitution", by Col. Curtis B. Dall & E. Stanley Rittenhouse] Listed here are a series of Executive Orders already approved which authorize the President to call a national emergency, and thereafter authorize the Federal Emergency Management Agency to mobilize other agencies to implement rationing and/or confiscation of public and private property==including food, guns, precious metals, businesses, homes, etc. •EXECUTIVE ORDERS• A. EO 10995 provides for the takeover of the communications media. B. EO 10997 provides for the takeover of all electric power, petroleum, gas and other fuels and minerals. C. EO 10998 provides for the takeover of all food resources and the nation's farms. D. EO 10999 provides for the takeover of all modes of transportation, control of highways, seaports etc. E. EO 11000 provides for mobilization of all civilians into work brigades under government supervision. F. EO 11001 provides for government takeover of all health and welfare functions. G. EO 11002 designates the postmaster general to operate national registration of all persons. H. EO 11003 provides for the government to takeover airports and aircraft. I. EO 11004 provides for the Housing and Finance Authority to relocate communities, designate areas to be abandoned and establish new locations for populations. J. EO 11005 provides for the government to take over railroads, inland waterways and public storage facilities. ------- All these Executive Orders were combined into one Executive Order 11490, which was signed by President Richard Nixon on October 28, 1969. On Sept. 26, 1961, Congress passed Public Law 87-297 which calls for arms control and the disarmament of the American people at the determination of the President. Legislation which has recently been signed into law and legislation now pending in Congress is moving toward the completion of this goal. On April 2, 1992 the U.S. Senate voted unanimously for SB 1425, which ratified the International Covenant on Civil and Political Rights. This Placed the human rights clause of the United Nations Charter in a superior position to our constitutional Bill of Rights, since the U.S. Supreme Court has ruled in Missouri v. Holland that a treaty supersedes the constitution. The acceptance of this treaty places judgment of American citizens under the umbrella of the United Nations and the world courts, where trials are not by a jury of our peers and judgments are not based on inalienable rights given to us by God and protected by the U.S. Constitution. • MONETARY: "A single currency, a single monetary policy, and a single authority issuing the currency and directing the monetary policy." {"Foreign Affairs," Fall 1984, Richard Cooper} In 1913 the U.S. Congress, in violation of the Constitution, turned control of the monetary system of the United States over to a privately owned organization of 12 individuals, 11 of whom are not citizens of the United States. Misleadingly called the Federal Reserve, this group manipulates the money supply and controls the debt of nations. This gives them the wealth and power to dictate the economic conditions of the world. [Secrets of the Federal Reserve, Eustice Mullins] A plan has been advanced by these men and their international partners to bring all nations under a single rule, with themselves in charge. By creating economic crises and the collapse of a nation's economy, they force those nations in debt to them to trade their assets-gold, natural resources, and land-for the backing of the International Monetary Fund, which they created and control. Once they own a nation's land and resources, they own and control that nation. [Ambushed, "Insider Report", Larry Abraham, p.12] They have made much progress toward this goal. Already every nation in the world is backed by the International Monetary Fund except the United States. Brazil, Argentina, Costa Rica, and other countries have been forced to trade assets and land to exonerate their debt. The specific plan to bring the U.S. under this monolithic control includes economic disruption, the collapse of more banks, and national bankruptcy. They believe under these conditions, most Americans will clamor for the "help" they offer, willingly trading our nation's land and resources for the backing of the International Monetary Fund to bail us out of our predicament. Their stated deadline to accomplish this goal is the year 2000. Many close observers believe it will take place much sooner. [Ambushed, "Insider Report". Larry Abraham p.12] Another method of obtaining control of a nation and it's lands is being accomplished in the United States with the help of the environmentalists. Wilderness areas are set aside, transferred to the Nature Conservancy, and then to the Federal Reserve, placing those lands under the direct control of these same individuals. [Ambushed, "Insider Report", Larry Abraham, p. 15-16] It is worth noting that the European countries recently met in the Netherlands and agreed to a single currency for all of Europe. • MILITARY: The plan is to control the armed forces of the world. The world has been divided into 10 regions. A country may do whatever it chooses within the confines of that region, but if it oversteps it's bounds it will be disciplined by the United Nations armed forces, economic forces, and judicial forces. Prior to the conflict in Kuwait a meeting was held to discuss the possibilities of a country that the combined forces of the United Nations could seize upon in the name of humanity to stamp out oppression and to show the strength of a world army. In early 1990 the American Ambassador to Iraq, April Glaspie, "had assured Saddam Hussein directly that the United States would take no action if he decided to invade Kuwait." It was agreed to cause another war similar in scale to the Iraqi war within 5 years, to keep the armed forces in focus and to remind the countries of the world of the power of the coalition forces. [Minutes of Bilderberger meeting, Baden-Baden Germany, August 1991, reported by James P. Tucker Jr.] As preparation for war was being made, Congress signed a treaty with the United Nations making George Bush the commander and chief of the coalition forces. Because the Supreme Court has ruled that a treaty takes precedence over the constitution, this treaty gave the President the power to declare war without meeting the Constitutional requirement of approval by Congress. This allows the president to unilaterally commit U.S. armed forces to United Nations wars all over the world. • JUDICIAL: The purpose is to place the world under a single judicial review to administer "justice" to the world. The World Court has no juries and is not bound by the individual rights protected by the U.S. Constitution. It will judge for "atrocities" against the world. Since the U.S. Supreme Court has {erroneously} ruled in Missouri v. Holland that treaties supersede the Constitution, every treaty the U.S. signs with the United Nations places interpretation and judgment in the jurisdiction of the World Court The Covenant on Political and Civil Rights, numerous environmental treaties, trade agreements, and other treaties have expanded jurisdiction to include economic, political, and environmental "crimes." Proposed treaties such as the "U.N. Covenant on the Rights of the Child" would expand the scope of that control to the very core of our society, the family. [Global Tyranny...Step by Step, William Jasper] • RELIGION: The plan is to establish a single humanistic religion for all the world. "Christianity will be outlawed and believers will face discrimination, persecution, and possibly elimination or imprisonment; there will be a new religion, first the worship of man, humanism, and then Satanism; and everyone will either accept the new religion or depart from that society." [The New World Order, Ralph A. Epperson, 1990, p.xx] "Cults" have been so discredited by the actions of some that few people question when a "cult" is verbally or even physically attacked by government. It is notable that those who are seeking to take control have redefined it to suit their purposes. Their definition is "anyone or any group [which] believes in the resurrection of Jesus Christ, and that Christ came back alive from the grave." ["A New Look at the New World Order," Kimber, audio tape] This definition will justify ostracism of Christians, while encouraging the growth of humanistic, occult, Satanistic religions. The core of the leaders of the secret society belong to an occult religion called the Illuminati. All organized witchcraft and all occult brotherhoods belong to it. The occult is the religion of the organization, not the organization itself. It is Luciferian in nature. [The Illuminati, Myron C. Fagan] The Illuminati uses a variety of tools. A few are discussed below. • Sorcery: In the New Testament, John uses the word sorcery in describing modern-day Babylon and the tools of the Beast. "The Greek word he uses is Pharmakeia, from which the word pharmacy is derived. Pharmakeia indicates the use of drugs, elixirs, and contraceptive potions associated with the occult. When freely accepted, these narcotics addict, desensitize, and deceive the nations, resulting in blindness and the inability to change. The use of drugs, simple and potent, is the same means by which the Mother of Abominations is able to deceive the nations." [Opening the Seven Seals, Richard D. Draper. p.109] • Immorality: Whether it be intimate relationships outside of the bonds of marriage, or pornography, abortion, prostitution, homosexuality, or any other form, immorality breaks down the character and fiber of an individual and destroys the foundation upon which freedom is based. • Idolatry: The new world order is seeking to establish a unified religion with generic beliefs, devoid of morals. This leads to idolatry, or the worship of something other than God. • Physical: The objective, as stated by one of their main spokesmen, Henry Kissinger, is to take control of food and oil. By controlling oil they control the militaries of the nations of the world. By controlling food, they can control individuals. [Christ vs. Satan, Oliver Demille, p.12] The U.S. Food and Drug Administration has promoted monopoly of medicines by certain very wealthy men. The recent proposals to require vitamins to be sold only with a prescription would extend that reach. Current popular proposals to restrict access to health care without government control would go to achieve this goal. Stiff penalties, including jail terms, for anyone who seeks or provides health care outside the government system are an integral part of the plan. "Global 2000 Report" written by former Secretary of State Cyrus Vance declares that the world needs to be depopulated"..by means of limited wars in the advanced countries, and by means of starvation and disease in the Third World Countries, the death of 3 billion people {described as "useless eaters"} by the year 2000." This report was accepted and approved for action by President Carter, for and on behalf of the United States Government, and accepted by Edwin Muskie, then Secretary of State. Under the terms of the Global 2000 Report, the population of the United States is to be reduced by 100 million by the year 2050. [Conspirator's Hierarchy, Dr. J. Coleman, p.22] These matters are serious. We can only prepare for them if we know about them. And once we know about them, we are obligated to act. "A man must not only stand for the right principles, he must also fight for them. Those who fight for principles can be proud of the friends they've gained and the enemies they've earned. We face days ahead that will test the moral and physical sinews of all of us. Those who hesitate to get into this fight because it is controversial fail to realize that life's decisions should be based on principles, not on polls." [Kzra Taft Benson, Secretary of Agriculture, Eisenhower Administration] We all need to learn the truth; it is truth that makes us free. May God grant us the wisdom and desire to search deeper and learn more, and the foresight to prepare without fear. This article is distributed by permission from the original distributor. Re-distributed by: TvF OUTREACH P.O. Box 42002 Las Vegas, Nevada 89116 TvFoutreach@webtv.net

### THE GREAT TRIBULATION THE GREAT TRIBULATION...THE MOST CATASTROPHIC EVENT EVER TO HAPPEN IN ALL OF EARTH'S HISTORY! Matthew 24:21 says; "For then shall be GREAT TRIBULATION, such as was not since the beginning of the world to this time, no, nor ever shall be." According to the prophecy in the book of Daniel, in Daniel 9:24-27, God tells Daniel that "70 weeks" (70 x 7 years) were 'determined upon Israel, and the HOLY CITY (Jerusalem), to make and end of sins, and to bring in everlasting righteousness, and to anoint the MOST HOLY'! Daniel 9: 25, 26 says; "Know therefore and understand, that from the going forth of the commandment to restore and to build Jerusalem (after the Babylonian captivity) unto Messiah...Prince (the Septuagint shows there is a separation between Messiah and Prince) shall be 7 weeks...and 62 weeks:...And after the 62 weeks shall Messiah (Jesus) be cut off, but not for himself: and the people of THE PRINCE (Antichrist) that shall come shall destroy the city and the sanctuary;..." THIS HAPPENED IN 70AD WHEN TITUS DESTROYED JERUSALEM AND THE TEMPLE! The Septuagint is the only remaining "accurate" translation of the Hebrew scriptures, so lets look at how the Septuagint reads Daniel 9: 26-27; "And after the 62 weeks, the anointed one (Jesus) shall be destroyed, and there is no judgment in him: and he shall destroy the city and the sanctuary with the PRINCE (Antichrist) that is coming...And 1 week shall establish the covenant with many: and in the MIDST OF THE WEEK my sacrifice and drink-offering shall be taken away (70ad): and on the TEMPLE shall be THE ABOMINATION OF DESOLATIONS; and at the END OF TIME an end shall be put to the desolation." (Jesus quoted from this Septuagint verse precisely---the KJV is not precise here!) These scriptures clearly show that after Jesus was crucified (62nd week) that there would be 7 MORE WEEKS (49 years) and then THE PRINCE (TITUS) would rise, and in the MIDDLE of the LAST WEEK OF DANIEL'S 70 WEEKS, THE PRINCE (TITUS) would destroy JERUSALEM and the TEMPLE! THIS HAPPENED IN 70AD! (Scholars now admit that Jesus was born years before the previously supposed date! All they had to do was read the book of Daniel!) So, since JERUSALEM AND THE TEMPLE were destroyed in the MIDDLE of the last 7 years of Daniel's prophecy....THERE STILL REMAINS 3 1/2 YEARS LEFT TO BE FULFILLED of Daniel's "70 weeks of years prophecy"! THIS IS WHAT THE "GREAT TRIBULATION IS REFERRING TO" ... "THE LAST 3 1/2 YEARS OF DANIEL'S PROPHECY"! If you will notice, ALL THROUGHT THE BOOK OF REVELATION---the Apostle John refers to the "Great Tribulation" as being "42 MONTHS, or 1260 DAYS...WHICH ALL EQUAL "3 1/2 YEARS"! Contrary to what we have been taught for so many years by inaccurate (so-called) prophecy teachers, THERE ARE ONLY 3 1/2 YEARS OF THE GREAT TRIBULATION... ACCORDING TO THE BIBLE! THE 1ST HALF of the "LAST 7 YEARS" happened in 70AD, when TITUS did the "ABOMINATION OF DESOLATION"! But, the Apostle John, in the book of Revelation, shows that THE LAST 3 1/2 YEARS WILL BE FULFILLED AT THE END TIME..."42 MONTHS"! The Bible says that THE ONE WHO DESTROYED JERUSALEM IN 70AD (TITUS), would have a DEADLY WOUND, but that he would RISE AGAIN at the END TIME, and FINISH THE LAST 3 1/2 YEARS of the 7 which were interrupted in the "MIDST OF DANIEL'S LAST WEEK"... in 70ad! This is what is meant by; "THE BEAST'S DEADLY WOUND WAS HEALED"! REVELATION 13 Revelation 13: 1-2 says; "And I stood upon the sand of the sea, and saw a beast rise up out of the sea, having 7 heads and 10 horns, and upon his horns 10 crowns, and upon his heads the name of blasphemy. And the beast which I saw WAS LIKE unto a leopard (Greece), and his feet were as the feet of a bear (Media Persia), and his mouth as the mouth of a lion (Babylon): (See Daniel 7 & 8) Notice that John mentions "ALL 4 KINGDOMS OF DANIEL 7"! John mentions THE LEOPARD--Greece, THE BEAR--Media Persia, THE LION--Babylon, and the 4th and last KINGDOM with 7 HEADS AND 10 HORNS--ROME! ROME is the last kingdom WITH 7 HEADS and 10 HORNS! People have gotten so OFF BASE in their interpretation of this prophecy! THE BEAST with 7 HEADS and 10 HORNS is ROME! So when John says in Revelation 17: 9-11; "And here is the mind which hath wisdom. The seven heads are 7 mountains on which the woman sitteth (Rome). And there are 7 kings: 5 are fallen, and 1 is, and the other is not yet come; and when he cometh, he must continue a short space. And the BEAST that was, and is not, even he is the 8th; and is of the 7, and goeth into perdition (destruction)." WHAT JOHN IS SAYING IS... (AT THE MOMENT HE WAS WRITING), that 5 ROMAN EMPERORS HAD FALLEN, and "ONE IS" (Nero), and another would come (Vespasian), and the 8th would be TITUS, who was of the 7! (Vespasian and his son Titus were CO-EMPERORS!) If you will check your encyclopedia, you will see that JOHN'S LINE-UP OF THE ROMAN EMPERORS ARE EXACTLY IN ORDER! And even the 3 "non authorized emperors" (i.e.--Galba, Otho, and Vitellius) ARE THE 3 THAT DANIEL 7:8 SAYS ARE "PLUCKED UP BY THE ROOTS"! Which is exactly what happened! After Nero died, these 3 tried to become Emperor before VESPASIAN AND TITUS! BUT ALL 3 were killed or committed suicide, "all in that same single year! And TITUS was right there to help facilitate their demise! THE PROPHECIES OF THE BIBLE ARE SO PRECISE...HOW CAN ANYONE "NOT SEE IT"! The entire world is aware of what happened to Jerusalem in 70ad! AND THE FALSE PROPHECY TEACHERS KNOW THIS AS WELL! And they have purposely DESIGNED A DIFFERENT SCENARIO, for the purpose of DISCOUNTING THE PROFOUND FULFILLMENT OF THIS AWSESOME PROPHECY! Apostate prophecy teachers want people to LOOK FOR THE WRONG SIGNS! They want people to think that the TEMPLE has to be RE-BUILT AGAIN, so that the ANTICHRIST can destroy it AGAIN! When Jesus planned for the Temple to be destroyed in 70ad, it was because, THE SACRIFICES WERE "DONE AWAY" THROUGH JESUS! AND JESUS WILL NOT REVERT BACK TO WHAT "HE HAS FINISHED"! This is why, in the book of Revelation, THERE ARE ONLY 42 MONTHS (3 ½ years) MENTIONED! The Great Tribulation is the FINAL 3 ½ YEARS LEFT OF "DANIEL'S 70 WEEKS OF YEARS PROPHECY TO ISRAEL"! Remember how Jesus said "THIS GENERATION SHALL NOT PASS, TILL ALL OF THESE THINGS BE FULFILLED", (i.e.--the things Jesus mentioned about the destruction of the Temple)! Many of the Apostles of Jesus DID live to see the "ABOMINATION OF DESOLATION" IN 70AD! This is why the Apostles Paul, Peter, John, and Jude WARNED PEOPLE ABOUT THE COMING DESOLATION! And John (of 1st John) came right out and said that THE ANTICHRIST WAS ALREADY ALIVE! And the Antichrist WAS already alive---in the person of TITUS, whom the Bible predicted would COME BACK ALIVE AT THE END TIME, AND FINISH THE LAST 3 ½ YEARS called "THE GREAT TRIBULATION"! And the Apostle John, in the book of Revelation, said that the ANTICHRIST would come back alive ("his deadly wound healed") "AT THE END TIME", and that the number of his name would equal 666! The most famous leader of our time is WILLIAM CLINTON! And of all things, WILLIAM CLINTON'S NAME EQUALS 666 in the biblical "Hebrew Alphabet"! (Please look for the "Hebrew Alphabet Numbering Chart" on this website's 'List of articles'! You will also find the Hebrew Alphabet in the BIBLE, in Psalms 119, paragraph headings!) TvF Outreach P.O. Box 42002 Las Vegas, NV 89116 TvFoutreach@webtv.net

### PLEASE REALIZE... PLEASE REALIZE: No one can change what God said "WILL HAPPEN"! Christians are NOT to physically fight the opposers of God! 2 Cor.10:4 says: "For the weapons of our warfare are not carnal (of this physical world), but mighty through God to the pulling down of strong holds;" Jesus said: "My kingdom is not of this world; if my kingdom were of this world, then my servants would fight..." (John 18:36) What Jesus DOES call us to do is to TRUST HIM AND PRAY ALWAYS--AND TO INFORM AND WARN ALL POSSIBLE...that all possible will be saved through the "redeeming blood of Jesus Christ"--and be able to "escape all these things that shall come to pass..." (Luke 21:36) TvF OUTREACH P.O. BOX 42002 LAS VEGAS, NEVADA 89116 TvFoutreach@webtv.net

### NATO: THE SLEEPING GIANT NATO is the acronym meaning "North Atlantic Treaty Organization"! They currently consist of 26 European member nations including the United States and Canada. The original signers/members of NATO in 1949 were: Belgium Canada Denmark France Iceland Italy Luxembourg Netherlands Norway Portugal United Kingdom United States NATO was signed by these 12 nations in WASHINGTON, DC on APRIL 4, 1949. "General Dwight D. Eisenhower, the leader of the western Allied forces in World War II, was named 'Supreme Allied Commander Europe' (SACEUR) by the North Atlantic Council (NATO's governing body) in December 1950. He was followed by a succession of U.S. generals as supreme Allied commanders." "NATO's first supreme commander was Dwight D. Eisenhower, World War II general and president of the United States from 1953 to 1961. Eisenhower's position gave the United States a leading role in NATO." THE UNITED STATES is the MOST POWERFUL LEADER of NATO! --------------- "THE PROPHETIC SIGNIFICANCE": Why is NATO so important in Bible prophecy? NATO, if you noticed above, is TOTALLY a EUROPEAN BLOCK OF NATIONS (including America), of which comprised most of "THE ANCIENT ROMAN EMPIRE"! The "EUROPEAN UNION" does not include the UNITED STATES, but "NATO DOES"! So, why is the UNITED STATES the most powerful member of NATO? Because the United States FOUNDED NATO! Furthermore, AMERICA itself was FOUNDED by EUROPE as their "PRIZED BRAIN-CHILD"! Bible prophecy predicts that THE BEAST will rise OUT OF the "10 HORNED NATIONS of the ANCIENT ROMAN EMPIRE" (ie--Europe and it's extended regions)! And of course, from THESE is exactly how AMERICA was BORN! Daniel 7: 7-8 says; "After this I saw in the night visions, and behold a fourth beast (Roman Empire), dreadful and terrible, and strong exceedingly; ....and it had 10 horns. I considered the horns, and behold, there came up among them another LITTLE HORN....and, behold, in THIS HORN were EYES like the eyes of man (Antichrist), and a mouth speaking great things." And Daniel 7:24, 25 says; "And the 10 horns out of this kingdom are 10 kings that SHALL arise: and ANOTHER shall rise AFTER them; and he shall be DIVERSE FROM THE FIRST...And he shall speak great words against the most High..."! And Daniel 2:44 says; "And in the days of THESE KINGS shall THE GOD OF HEAVEN set up a KINGDOM, which shall NEVER BE DESTROYED:..."! Clearly we see that the REVIVED ROMAN EMPIRE will rise again through THESE (end time) 10 HORNED NATIONS, which gave birth to the LITTLE HORN (U.S.) which is the STRONGEST OF ALL! (See Daniel 7:20) The UNITED STATES was NOT born through the "192 GLOBAL member nations of the UNITED NATIONS" (of which the United States itself founded)! AMERICA was BORN through EUROPE, which is now also called NATO! Which are of the original nations of the "ANCIENT ROMAN EMPIRE"! NATO, THE G8, and THE EUROPEAN UNION are all members of THE UNITED NATIONS! However, the United Nations include virtually ALL NATIONS on the PLANET! And the European Union includes ONLY Europe! "Only NATO and the G8 include EUROPE "AND" the UNITED STATES"! So we can see that NATO or THE G8 (which will be G10) are the ONLY CANDIDATES that FIT the BIBLE PROPHECIES of the "10 HORNS" from the "ANCIENT ROMAN EMPIRE", which will produce "THE ANTICHRIST"! President WILLIAM CLINTON signed the "NATO EXPANSION RATIFICATION" on May 21, 1998 at a White House event in the Rose Garden! It is very important to know that "WILLIAM CLINTON'S NAME EQUALS 666 in the Hebrew alphabet". (You will find the "Hebrew Alphabet Numbering Chart" on "page 1" of this website.) Now maybe we can understand why the MASONIC FOREFATHERS of America named the SEAT of it's government "CAPITOL HILL"! CAPITOL HILL is the name of "ROME"! Look up CAPITOL in the dictionary! And this is also why the buildings at Capitol Hill are designed after ROMAN STYLE -- (not England, Russian, Spanish, Asian, etc.)! AND THIS IS WHY "NEW YORK" IS CALLED "THE EMPIRE STATE"! Even the UNITED STATES GOVERNMENT is based on the ANCIENT Greek/ROMAN GOVERNMENT (ie--senators , military, voting, democracy, etc.)! THE BEAST isn't to RISE from Europe ITSELF! It was EUROPE who FOUNDED AMERICA -- THE LITTLE HORN -- THE MOST POWERFUL NATION IN ALL HISTORY! So keep your eyes on NATO, which the United States founded, and was the MOST SIGNIFICANT of the ORIGINAL SIGNERS on April 4, 1949, in WASHINGTON, DC! According to Bible prophecy, 10 of the strongest nations of NATO (which are also members of the United Nations), will give their "POWER AND STRENGTH TO THE BEAST"! (See Revelation 17:12-13) So be aware of the "SLEEPING GIANT"! TvF OUTREACH PO Box 42002 Las Vegas, NV 89116 (702) 453-3348 TvFoutreach@webtv.net

### Origin of: THE ROMAN CATHOLIC CHURCH Have you ever wondered why much of the ancient manuscripts of "The Holy Scriptures" ended up in the hands of "THE ROMAN CATHOLIC CHURCH", at the VATICAN in ROME??? In 70 AD, when TITUS destroyed JERUSALEM and the TEMPLE, TITUS took all of the "sacred things" from the Temple, INCLUDING THE "HOLY SCRIPTURES" and put them in his "PAGAN TEMPLE IN ROME"!!! (You will find this documentation in the "Books of Josephus", "The Jewish Wars"!) Also, click the following site to see the "Arch of Titus" (still standing in Rome) which depicts some of the 'treasures' Titus took from the Jewish Temple in 70ad: http://www.bluffton.edu/~sullivanm/titus/titus.html Josephus was a Jewish historian, also a Priest, who joined with Titus! And at the request of Titus, he was there to watch and record the "destruction of Jerusalem and the Temple"! Josephus went back to ROME with Titus, and thus, with all of these "Sacred Scriptures" in their hands at Rome, they had what they needed to lay the foundation for "The Universal Roman Catholic Church"! With these "Sacred Scriptures" now in their hands, ROME would be able to devise a "FAKE CHRISTIAN CHURCH", that would look VALID to the ignorant, because much of "THE SACRED SCRIPTURES" WERE NOW IN THE POSSESSION OF ROME! JESUS "did not" begin His "Ekklesia, The Body of Christ", OUT OF ROME -- SATAN'S 4TH (PROPHESIED) KINGDOM! (And sadly, Protestant churches are founded on this same origin! But, the true "Body of Christ" has continued, but not in temples made with hands! Trust only Jesus!) TvF OUTREACH P.O. BOX 42002 LAS VEGAS, NV 89116 (702) 453-3348 TvFoutreach@webtv.net

### HUMAN CLONING ALERT According to the Bible and qualified in the book of Jude (esp. 4,6,7,14), "demons" are the spirits of the offspring of the "fallen angels' union with women", mentioned in Genesis 6. (See Matt.12:43-45) GOD created human life with the capability also, of reproducing a human body that DOES NOT CONTAIN A SOUL OR SPIRIT, through (for want of a better word) "CLONING"! JESUS was righteously born through the process of placing the DNA of DAVID (Acts 2:29-34, Isa. 11:1, Luke 1:31-35) into the "egg-shell" of Mary (without sperm) to give Jesus a "human body" that DID NOT have a soul or spirit in it--in order for the "divine, sinless person of Jesus" to enter this world in a human body, to pay for our sins on the "cross" [THIS IS PROOF OF THE VIRGIN BIRTH]! Satan is wickedly using this similar process to make "human bodies" that DO NOT have a soul or spirit in it -- in order to give the "demons" a body again! (Jude 4,12,13,14) Some are here already -- including the Antichrist! (See the following article "Titus--of 70 AD Reborn".) THIS HELPS EXPLAIN THE MYSTERY OF THE "BABY BOOM" (Hitler's plan for a superior race)! TvF OUTREACH P.O. BOX 42002 Las Vegas, NV 89116 (702) 453-3348 TvFoutreach@webtv.net

### TITUS--OF 70AD REBORN Daniel 8: 9-11 & 11:31 says that the ANTICHRIST would be the one who would destroy Jerusalem, the Temple, and the sacrifices! This is called the "abomination of desolation"! THIS HAPPENED IN 70AD! TITUS was the one who did this! Futhermore, Titus brought his "idols" into the Temple, and poluted the Sanctuary! When he died young , while Emperor of Rome, his brother Domitian was suspected of killing him! Revelation 13: 3-5 says the BEAST (TITUS) with the "deadly wound" WOULD BE HEALED! He would come back to life again, at the "end time", and rule the world for the last 3 1/2 years of the 7 that split in 70AD. THIS IS WHAT IS MEANT BY THE BEAST'S "DEADLY WOUND WAS HEALED"! GOD has certainly blessed us here in America! But the fact still remains, that it was people from nations which were part of the "Ancient Roman Empire" (England, Italy, Spain, etc.) who sailed across the Sea and erected "America the Great"! Columbus was in fact--born in Italy! So, according to the Bible, the BEAST, whose name equals 666 in the Hebrew alphabet, is actually the re-born Emperor TITUS, but of course, by his re-born name! (See Rev. 17) An ex-president's name equals 666 in "The Hebrew Alphabet Numbering Chart"! (Check it out on our "front page") For centuries we have been taught many different things! But God said these prophecies would be sealed and not fully understood "until the time of the end"! WE ARE IN THAT TIME! TvF OUTREACH P.O. BOX 42002 LAS VEGAS, NV 89116 (702) 453-3348 TvFoutreach@webtv.net

| Powered by MSN TV |